//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithGot](index.md)/[discardToAdvance](discard-to-advance.md)

# discardToAdvance

[common]\
val [discardToAdvance](discard-to-advance.md): [Map](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md), [ShantenWithoutGot](../-shanten-without-got/index.md)&gt;

每种弃牌后的向听信息
